pub struct Avx2Math;Expand description
Concrete implementation of the SimdMath trait for processors with AVX2 and FMA support.
This is where we “connect the wires”: we connect the abstract mathematical operations of the system to the ultra-fast functions documented above. This struct ensures that NAM-rs takes full advantage of modern hardware to process audio in real time.